/* options2.h */

extern void optsave P_((BUFFER custom));
